==> mima_engine-0.2.0-py3-none-any.whl: mima/util/input_defaults.py <==
from ..types.keys import Key as K

BUTTONS = [
    K.UP,
    K.DOWN,
    K.LEFT,
    K.RIGHT,
    K.START,
    K.SELECT,
    K.A,
    K.B,
    K.X,
    K.Y,
    K.L,
    K.R,
    K.P1_UP,
    K.P1_DOWN,
    K.P1_LEFT,
    K.P1_RIGHT,
    K.P1_START,
    K.P1_SELECT,
    K.P1_A,
    K.P1_B,
    K.P1_X,
    K.P1_Y,
    K.P1_L,
    K.P1_R,
    K.P2_UP,
    K.P2_DOWN,
    K.P2_LEFT,
    K.P2_RIGHT,
    K.P2_START,
    K.P2_SELECT,
    K.P2_A,
    K.P2_B,
    K.P2_X,
    K.P2_Y,
    K.P2_L,
    K.P2_R,
    K.P3_UP,
    K.P3_DOWN,
    K.P3_LEFT,
    K.P3_RIGHT,
    K.P3_START,
    K.P3_SELECT,
    K.P3_A,
    K.P3_B,
    K.P3_X,
    K.P3_Y,
    K.P3_L,
    K.P3_R,
    K.P4_UP,
    K.P4_DOWN,
    K.P4_LEFT,
    K.P4_RIGHT,
    K.P4_START,
    K.P4_SELECT,
    K.P4_A,
    K.P4_B,
    K.P4_X,
    K.P4_Y,
    K.P4_L,
    K.P4_R,
]


# Keyboard
# The arrow keys need to be uppercase, other keys are lowercase
DEFAULT_KEYBOARD_MAP = {
    K.UP: ["w", "UP"],
    K.DOWN: ["s", "DOWN"],
    K.LEFT: ["a", "LEFT"],
    K.RIGHT: ["d", "RIGHT"],
    K.START: ["i"],
    K.SELECT: ["t"],
    K.A: ["k"],
    K.B: ["h"],
    K.X: ["l"],
    K.Y: ["j"],
    K.L: ["o"],
    K.R: ["c"],
    K.P1_UP: [],
    K.P1_DOWN: [],
    K.P1_LEFT: [],
    K.P1_RIGHT: [],
    K.P1_START: [],
    K.P1_SELECT: [],
    K.P1_A: [],
    K.P1_B: [],
    K.P1_X: [],
    K.P1_Y: [],
    K.P1_L: [],
    K.P1_R: [],
    K.P1_UP: [],
    K.P1_UP: [],
    K.P2_DOWN: [],
    K.P2_LEFT: [],
    K.P2_RIGHT: [],
    K.P2_START: [],
    K.P2_SELECT: [],
    K.P2_A: [],
    K.P2_B: [],
    K.P2_X: [],
    K.P2_Y: [],
    K.P2_L: [],
    K.P2_R: [],
    K.P2_UP: [],
    K.P3_UP: [],
    K.P3_DOWN: [],
    K.P3_LEFT: [],
    K.P3_RIGHT: [],
    K.P3_START: [],
    K.P3_SELECT: [],
    K.P3_A: [],
    K.P3_B: [],
    K.P3_X: [],
    K.P3_Y: [],
    K.P3_L: [],
    K.P3_R: [],
    K.P4_UP: [],
    K.P4_DOWN: [],
    K.P4_LEFT: [],
    K.P4_RIGHT: [],
    K.P4_START: [],
    K.P4_SELECT: [],
    K.P4_A: [],
    K.P4_B: [],
    K.P4_X: [],
    K.P4_Y: [],
    K.P4_L: [],
    K.P4_R: [],
}

DEFAULT_JOYSTICK_MAP = {
    K.UP: ["up"],
    K.DOWN: ["down"],
    K.LEFT: ["left"],
    K.RIGHT: ["right"],
    K.START: [7],
    K.SELECT: [6],
    K.A: [0],
    K.B: [1],
    K.X: [3],
    K.Y: [2],
    K.L: [4],
    K.R: [5],
}

DEFAULT_TOUCHSCREEN_MAP = {
    K.UP: [[0, 0], [0.5, 1.0]],
    K.L: [[0, 0], [0.0625, 0.1111]],
    K.R: [[0.9375, 0], [1.0, 0.1111]],
    K.START: [[0.5, 0], [1.0, 0.3]],
    K.Y: [[0.5, 0.3], [0.75, 0.5]],
    K.X: [[0.75, 0.3], [1.0, 0.5]],
    K.B: [[0.5, 0.5], [0.75, 1.0]],
    K.A: [[0.75, 0.5], [1.0, 1.0]],
}

==> mima_engine-0.2.2-py3-none-any.whl: mima/util/input_defaults.py <==
from ..types.keys import Key as K

BUTTONS = [
    K.UP,
    K.DOWN,
    K.LEFT,
    K.RIGHT,
    K.START,
    K.SELECT,
    K.A,
    K.B,
    K.X,
    K.Y,
    K.L,
    K.R,
    K.P1_UP,
    K.P1_DOWN,
    K.P1_LEFT,
    K.P1_RIGHT,
    K.P1_START,
    K.P1_SELECT,
    K.P1_A,
    K.P1_B,
    K.P1_X,
    K.P1_Y,
    K.P1_L,
    K.P1_R,
    K.P2_UP,
    K.P2_DOWN,
    K.P2_LEFT,
    K.P2_RIGHT,
    K.P2_START,
    K.P2_SELECT,
    K.P2_A,
    K.P2_B,
    K.P2_X,
    K.P2_Y,
    K.P2_L,
    K.P2_R,
    K.P3_UP,
    K.P3_DOWN,
    K.P3_LEFT,
    K.P3_RIGHT,
    K.P3_START,
    K.P3_SELECT,
    K.P3_A,
    K.P3_B,
    K.P3_X,
    K.P3_Y,
    K.P3_L,
    K.P3_R,
    K.P4_UP,
    K.P4_DOWN,
    K.P4_LEFT,
    K.P4_RIGHT,
    K.P4_START,
    K.P4_SELECT,
    K.P4_A,
    K.P4_B,
    K.P4_X,
    K.P4_Y,
    K.P4_L,
    K.P4_R,
]


# Keyboard
# The arrow keys need to be uppercase, other keys are lowercase
DEFAULT_KEYBOARD_MAP = {
    K.UP: ["w", "UP"],
    K.DOWN: ["s", "DOWN"],
    K.LEFT: ["a", "LEFT"],
    K.RIGHT: ["d", "RIGHT"],
    K.START: ["i"],
    K.SELECT: ["t"],
    K.A: ["k"],
    K.B: ["h"],
    K.X: ["l"],
    K.Y: ["j"],
    K.L: ["o"],
    K.R: ["c"],
    K.P1_UP: [],
    K.P1_DOWN: [],
    K.P1_LEFT: [],
    K.P1_RIGHT: [],
    K.P1_START: [],
    K.P1_SELECT: [],
    K.P1_A: [],
    K.P1_B: [],
    K.P1_X: [],
    K.P1_Y: [],
    K.P1_L: [],
    K.P1_R: [],
    K.P1_UP: [],
    K.P1_UP: [],
    K.P2_DOWN: [],
    K.P2_LEFT: [],
    K.P2_RIGHT: [],
    K.P2_START: [],
    K.P2_SELECT: [],
    K.P2_A: [],
    K.P2_B: [],
    K.P2_X: [],
    K.P2_Y: [],
    K.P2_L: [],
    K.P2_R: [],
    K.P2_UP: [],
    K.P3_UP: [],
    K.P3_DOWN: [],
    K.P3_LEFT: [],
    K.P3_RIGHT: [],
    K.P3_START: [],
    K.P3_SELECT: [],
    K.P3_A: [],
    K.P3_B: [],
    K.P3_X: [],
    K.P3_Y: [],
    K.P3_L: [],
    K.P3_R: [],
    K.P4_UP: [],
    K.P4_DOWN: [],
    K.P4_LEFT: [],
    K.P4_RIGHT: [],
    K.P4_START: [],
    K.P4_SELECT: [],
    K.P4_A: [],
    K.P4_B: [],
    K.P4_X: [],
    K.P4_Y: [],
    K.P4_L: [],
    K.P4_R: [],
}

DEFAULT_JOYSTICK_MAP = {
    K.UP: ["up"],
    K.DOWN: ["down"],
    K.LEFT: ["left"],
    K.RIGHT: ["right"],
    K.START: [7],
    K.SELECT: [6],
    K.A: [0],
    K.B: [1],
    K.X: [3],
    K.Y: [2],
    K.L: [4],
    K.R: [5],
}

DEFAULT_TOUCHSCREEN_MAP = {
    K.P1_UP: [[0, 0], [0.5, 1.0]],
    K.P1_L: [[0, 0], [0.0625, 0.1111]],
    K.P1_R: [[0.9375, 0], [1.0, 0.1111]],
    K.P1_START: [[0.5, 0], [1.0, 0.3]],
    K.P1_Y: [[0.5, 0.3], [0.75, 0.5]],
    K.P1_X: [[0.75, 0.3], [1.0, 0.5]],
    K.P1_B: [[0.5, 0.5], [0.75, 1.0]],
    K.P1_A: [[0.75, 0.5], [1.0, 1.0]],
}
